==> firefox-101.0b7.source.tar.xz: firefox-101.0/dom/ipc/VsyncMainChild.cpp <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "VsyncMainChild.h"

#include "mozilla/SchedulerGroup.h"
#include "mozilla/VsyncDispatcher.h"
#include "nsThreadUtils.h"

namespace mozilla::dom {

VsyncMainChild::VsyncMainChild()
    : mIsShutdown(false), mVsyncRate(TimeDuration::Forever()) {
  MOZ_ASSERT(NS_IsMainThread());
}

VsyncMainChild::~VsyncMainChild() { MOZ_ASSERT(NS_IsMainThread()); }

void VsyncMainChild::AddChildRefreshTimer(VsyncObserver* aVsyncObserver) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mObservers.Contains(aVsyncObserver));

  if (mIsShutdown) {
    return;
  }

  if (mObservers.IsEmpty()) {
    Unused << PVsyncChild::SendObserve();
  }
  mObservers.AppendElement(std::move(aVsyncObserver));
}

void VsyncMainChild::RemoveChildRefreshTimer(VsyncObserver* aVsyncObserver) {
  MOZ_ASSERT(NS_IsMainThread());
  if (mIsShutdown) {
    return;
  }

  if (mObservers.RemoveElement(aVsyncObserver) && mObservers.IsEmpty()) {
    Unused << PVsyncChild::SendUnobserve();
  }
}

void VsyncMainChild::ActorDestroy(ActorDestroyReason aActorDestroyReason) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mIsShutdown);
  mIsShutdown = true;

  if (!mObservers.IsEmpty()) {
    Unused << PVsyncChild::SendUnobserve();
  }
  mObservers.Clear();
}

mozilla::ipc::IPCResult VsyncMainChild::RecvNotify(const VsyncEvent& aVsync,
                                                   const float& aVsyncRate) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mIsShutdown);

  SchedulerGroup::MarkVsyncRan();

  mVsyncRate = TimeDuration::FromMilliseconds(aVsyncRate);

  for (VsyncObserver* observer : mObservers.ForwardRange()) {
    observer->NotifyVsync(aVsync);
  }
  return IPC_OK();
}

TimeDuration VsyncMainChild::GetVsyncRate() { return mVsyncRate; }

}  // namespace mozilla::dom

==> firefox-146.0.1.source.tar.xz: firefox-146.0.1/dom/ipc/VsyncMainChild.cpp <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim: set ts=8 sts=2 et sw=2 tw=80: */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#include "VsyncMainChild.h"

#include "mozilla/SchedulerGroup.h"
#include "mozilla/VsyncDispatcher.h"
#include "nsThreadUtils.h"

namespace mozilla::dom {

VsyncMainChild::VsyncMainChild()
    : mIsShutdown(false), mVsyncRate(TimeDuration::Forever()) {
  MOZ_ASSERT(NS_IsMainThread());
}

VsyncMainChild::~VsyncMainChild() { MOZ_ASSERT(NS_IsMainThread()); }

void VsyncMainChild::AddChildRefreshTimer(VsyncObserver* aVsyncObserver) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mObservers.Contains(aVsyncObserver));

  if (mIsShutdown) {
    return;
  }

  if (mObservers.IsEmpty()) {
    (void)PVsyncChild::SendObserve();
  }
  mObservers.AppendElement(std::move(aVsyncObserver));
}

void VsyncMainChild::RemoveChildRefreshTimer(VsyncObserver* aVsyncObserver) {
  MOZ_ASSERT(NS_IsMainThread());
  if (mIsShutdown) {
    return;
  }

  if (mObservers.RemoveElement(aVsyncObserver) && mObservers.IsEmpty()) {
    (void)PVsyncChild::SendUnobserve();
  }
}

void VsyncMainChild::ActorDestroy(ActorDestroyReason aActorDestroyReason) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mIsShutdown);
  mIsShutdown = true;

  if (!mObservers.IsEmpty()) {
    (void)PVsyncChild::SendUnobserve();
  }
  mObservers.Clear();
}

mozilla::ipc::IPCResult VsyncMainChild::RecvNotify(const VsyncEvent& aVsync,
                                                   const float& aVsyncRate) {
  MOZ_ASSERT(NS_IsMainThread());
  MOZ_ASSERT(!mIsShutdown);

  mVsyncRate = TimeDuration::FromMilliseconds(aVsyncRate);

  for (RefPtr<VsyncObserver> observer : mObservers.ForwardRange()) {
    observer->NotifyVsync(aVsync);
  }
  return IPC_OK();
}

TimeDuration VsyncMainChild::GetVsyncRate() { return mVsyncRate; }

}  // namespace mozilla::dom
